"use strict";

var _interopRequire = function (obj) { return obj && obj.__esModule ? obj["default"] : obj; };

var _createClass = (function () { function defineProperties(target, props) { for (var key in props) { var prop = props[key]; prop.configurable = true; if (prop.value) prop.writable = true; } Object.defineProperties(target, props); } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _classCallCheck = function (instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } };

Object.defineProperty(exports, "__esModule", {
  value: true
});

var axios = _interopRequire(require("axios"));

var Promise = _interopRequire(require("bluebird"));

var toml = _interopRequire(require("toml"));

var Config = require("./config").Config;

// STELLAR_TOML_MAX_SIZE is the maximum size of rover.toml file
var STELLAR_TOML_MAX_SIZE = 100 * 1024;

exports.STELLAR_TOML_MAX_SIZE = STELLAR_TOML_MAX_SIZE;
/**
 * RoverTomlResolver allows resolving `rover.toml` files.
 */

var RoverTomlResolver = exports.RoverTomlResolver = (function () {
  function RoverTomlResolver() {
    _classCallCheck(this, RoverTomlResolver);
  }

  _createClass(RoverTomlResolver, null, {
    resolve: {
      /**
       * Returns a parsed `rover.toml` file for a given domain.
       * Returns a `Promise` that resolves to the parsed rover.toml object. If `rover.toml` file does not exist for a given domain or is invalid Promise will reject.
       * ```js
       * RoverSdk.RoverTomlResolver.resolve('acme.com')
       *   .then(roverToml => {
       *     // roverToml in an object representing domain rover.toml file.
       *   })
       *   .catch(error => {
       *     // rover.toml does not exist or is invalid
       *   });
       * ```
       * @see <a href="https://www.rover.org/developers/learn/concepts/rover-toml.html" target="_blank">Rover .toml doc</a>
       * @param {string} domain Domain to get rover.toml file for
       * @param {object} [opts]
       * @param {boolean} [opts.allowHttp] - Allow connecting to http servers, default: `false`. This must be set to false in production deployments!
       * @returns {Promise}
       */

      value: function resolve(domain) {
        var opts = arguments[1] === undefined ? {} : arguments[1];

        var allowHttp = Config.isAllowHttp();
        if (typeof opts.allowHttp !== "undefined") {
          allowHttp = opts.allowHttp;
        }

        var protocol = "https";
        if (allowHttp) {
          protocol = "http";
        }
        return axios.get("" + protocol + "://" + domain + "/.well-known/rover.toml", { maxContentLength: STELLAR_TOML_MAX_SIZE }).then(function (response) {
          try {
            var tomlObject = toml.parse(response.data);
            return Promise.resolve(tomlObject);
          } catch (e) {
            return Promise.reject(new Error("Parsing error on line " + e.line + ", column " + e.column + ": " + e.message));
          }
        })["catch"](function (err) {
          if (err.message.match(/^maxContentLength size/)) {
            throw new Error("rover.toml file exceeds allowed size of " + STELLAR_TOML_MAX_SIZE);
          } else {
            throw err;
          }
        });
      }
    }
  });

  return RoverTomlResolver;
})();